@@ -1,12 +1,13 @@
 import tempfile
 import os
+import os.path as op
 
 
-freesurfer_reg_to_native = os.environ.get('FREESURFER_REG_TO_NATIVE', 1) == 1
+freesurfer_reg_to_native = os.environ.get('FREESURFER_REG_TO_NATIVE', 0) == '1'
 
 
 def __is_valid_scan__(xnat_instance, scan):
-    ''' Checks if a scan is valid according to a set of rules '''
+    """ Checks if a scan is valid according to a set of rules """
     valid = False
     import fnmatch
     prefix = [i.split('/')[0] for i in scan.keys()
@@ -25,21 +26,20 @@ def __is_valid_scan__(xnat_instance, scan):
 
 
 def __get_T1__(x, experiment_id, sequence='T1_ALFA1'):
-    t2_lut_names = [sequence]
-    t2_scans = []
+    t1_lut_names = [sequence]
+    t1_scans = []
     scans = x.array.mrscans(experiment_id=experiment_id,
                             columns=['xnat:mrScanData/quality',
                                      'xnat:mrScanData/type',
                                      'xsiType']).data
+    e = x.select.experiment(experiment_id)
     for s in scans:
-        e = x.select.experiment(experiment_id)
-
         scan = e.scan(s['xnat:mrscandata/id'])
-        if scan.attrs.get('type').rstrip(' ') in t2_lut_names and\
-           __is_valid_scan__(x, s):
-            t2_scans.append(scan.id())
-    assert(len(t2_scans) == 1)
-    files = list(e.scan(t2_scans[0]).resource('NIFTI').files('*.nii.gz'))
+        if scan.attrs.get('type').rstrip(' ') in t1_lut_names and\
+                __is_valid_scan__(x, s):
+            t1_scans.append(scan.id())
+    assert(len(t1_scans) == 1)
+    files = list(e.scan(t1_scans[0]).resource('NIFTI').files('*.nii.gz'))
     return files[0]
 
 
@@ -50,8 +50,8 @@ def __get_T2__(x, experiment_id, sequence='T2_ALFA1'):
                             columns=['xnat:mrScanData/quality',
                                      'xnat:mrScanData/type',
                                      'xsiType']).data
+    e = x.select.experiment(experiment_id)
     for s in scans:
-        e = x.select.experiment(experiment_id)
         scan = e.scan(s['xnat:mrscandata/id'])
 
         if scan.attrs.get('type').rstrip(' ') in t2_lut_names and\
@@ -64,9 +64,8 @@ def __get_T2__(x, experiment_id, sequence='T2_ALFA1'):
 
 
 def __download_freesurfer6__(x, experiment_id, destination,
-                                resource_name='FREESURFER6',
-                                raw=True, cache=False): #, labels=None):
-    import os.path as op
+                             resource_name='FREESURFER6',
+                             raw=True, cache=False):
     filepaths = []
     e = x.select.experiment(experiment_id)
     r = e.resource(resource_name)
@@ -75,8 +74,8 @@ def __download_freesurfer6__(x, experiment_id, destination,
         fp1 = op.join(destination, '%s_T1.nii.gz' % experiment_id)
         filepaths.append(fp1)
         if not cache:
-            t2_t1space = __get_T1__(x, experiment_id)
-            t2_t1space.get(fp1)
+            t1_file = __get_T1__(x, experiment_id)
+            t1_file.get(fp1)
     else:
         filepaths.append(None)
 
@@ -95,12 +94,14 @@ def __download_freesurfer6__(x, experiment_id, destination,
     bg = filepaths[1]
 
     # Note that the filepaths for these new steps are not stored/returned
-    aseg.__preproc_aseg__(aseg_fp, bg, cache=cache)
+    if freesurfer_reg_to_native:
+        aseg.__preproc_aseg__(aseg_fp, bg, cache=cache)
     aseg.__swap_fs__(aseg_fp, cache=cache)
     aseg.__swap_fs__(bg, cache=cache)
 
     import logging as log
-    log.info('freesurfer_reg_to_native:', freesurfer_reg_to_native)
+    log.basicConfig(level=log.INFO)
+    log.info('freesurfer_reg_to_native: %s' % freesurfer_reg_to_native)
 
     bg = filepaths[0]
 
@@ -114,17 +115,60 @@ def __download_freesurfer6__(x, experiment_id, destination,
         aseg_fp = aseg.__swap_fs__(aseg_fp, cache=True)
         bg = aseg.__swap_fs__(filepaths[1], cache=True)
 
-    print(bg, aseg_fp)
-    filepaths = [bg]
-    # if labels is not None:
-    #     aseg_fp = aseg.__picklabel_fs__(aseg_fp, labels=labels)
-    filepaths.append(aseg_fp)
-    print(filepaths)
+    return [bg, aseg_fp]
+
+
+def __download_spm12__(x, experiment_id, destination,
+                       resource_name='SPM12_SEGMENT',
+                       raw=True, cache=False):
+    filepaths = []
+    e = x.select.experiment(experiment_id)
+    r = e.resource(resource_name)
+
+    if raw:
+        fp1 = op.join(destination, '%s_T1.nii.gz' % experiment_id)
+        filepaths.append(fp1)
+        if not cache:
+            t1_file = __get_T1__(x, experiment_id)
+            t1_file.get(fp1)
+
+    else:
+        filepaths.append(None)
+
+    r = e.resource(resource_name)
+    files = ['c1', 'c2', 'c3']
+    if resource_name == 'SPM12_SEGMENT_T2T1':
+        files = ['c1', 'filled_c2', 'c3']
+    for each in files:
+        c = list(r.files('%s*.nii.gz' % each))[0]
+        fp = op.join(destination, '%s_%s_%s.nii.gz'
+                                  % (experiment_id, resource_name, each))
+        if not cache:
+            c.get(fp)
+        filepaths.append(fp)
+
     return filepaths
 
 
-def download_resources(config, experiment_id, resource_name,  destination,
-                       raw=True, cache=False):
+def __download_ashs__(x, experiment_id, destination, resource_name='ASHS',
+                      raw=True, cache=False):
+    filepaths = []
+    e = x.select.experiment(experiment_id)
+    r = e.resource(resource_name)
+
+    r = e.resource(resource_name)
+    for each in ['tse.nii.gz', 'left_lfseg_corr_nogray.nii.gz']:
+        c = list(r.files('*%s' % each))[0]
+        fp = op.join(destination, '%s_%s_%s' % (experiment_id,
+                                                resource_name, each))
+        if not cache:
+            c.get(fp)
+        filepaths.append(fp)
+    return filepaths
+
+
+def download_resources(config, experiment_id, resource_name,
+                       destination, raw=True, cache=False):
     """Download a given experiment/resource from an XNAT instance in a local
     destination folder.
 
@@ -169,50 +213,22 @@ def download_resources(config, experiment_id, resource_name,  destination,
         filepaths
 
     """
-    import os.path as op
     import pyxnat
     x = pyxnat.Interface(config=config)
     filepaths = []
     e = x.select.experiment(experiment_id)
 
     if 'SPM12' in resource_name:
-
-        if raw:
-            fp1 = op.join(destination, '%s_T2_T1space.nii.gz' % experiment_id)
-            # fp1 = op.join(destination, '%s_T1.nii.gz'%experiment_id)
-            filepaths.append(fp1)
-            if not cache:
-                t2_t1space = __get_T2__(x, experiment_id)
-                t2_t1space.get(fp1)
-
-        else:
-            filepaths.append(None)
-
-        r = e.resource(resource_name)
-        files = ['c1', 'c2', 'c3']
-        if resource_name == 'SPM12_SEGMENT_T2T1_COREG3':
-            files = ['c1', 'filled_c2', 'c3']
-        for each in files:
-            c = list(r.files('%s*.nii.gz' % each))[0]
-            fp = op.join(destination, '%s_%s_%s.nii.gz'
-                                      % (experiment_id, resource_name, each))
-            if not cache:
-                c.get(fp)
-            filepaths.append(fp)
+        filepaths = __download_spm12__(x, experiment_id, destination,
+                                       resource_name, raw, cache)
 
     elif resource_name == 'ASHS':
-        r = e.resource(resource_name)
-        for each in ['tse.nii.gz', 'left_lfseg_corr_nogray.nii.gz']:
-            c = list(r.files('*%s' % each))[0]
-            fp = op.join(destination, '%s_%s_%s' % (experiment_id,
-                                                    resource_name, each))
-            if not cache:
-                c.get(fp)
-            filepaths.append(fp)
+        filepaths = __download_ashs__(x, experiment_id, destination,
+                                      resource_name, raw, cache)
 
     elif 'FREESURFER6' in resource_name:
         filepaths = __download_freesurfer6__(x, experiment_id, destination,
-                                                resource_name, raw, cache)
+                                             resource_name, raw, cache)
 
     elif 'CAT12' in resource_name:
         if raw:
@@ -239,15 +255,14 @@ def download_resources(config, experiment_id, resource_name,  destination,
             if f is None and not raw:
                 continue
             if not op.isfile(f):
-                msg = 'No such file: \'%s\'. Retry with cache set to False.'\
-                        % f
+                msg = 'No such file: \'%s\'. Retry with cache set to False.' % f
                 raise FileNotFoundError(msg)
 
     return filepaths
 
 
 def plot_segment(config, experiment_id, savefig=None, slices=None,
-                 resource_name='SPM12_SEGMENT_T2T1_COREG',
+                 resource_name='SPM12_SEGMENT',
                  axes='xyz', raw=True, opacity=10, animated=False,
                  rowsize=None, figsize=None, contours=False, cache=False,
                  samebox=False):
@@ -274,7 +289,7 @@ def plot_segment(config, experiment_id, savefig=None, slices=None,
 
     resource_name: string, optional
         Name of the resource where the segmentation maps are stored in the XNAT
-        instance. Default: SPM12_SEGMENT_T2T1_COREG
+        instance. Default: SPM12_SEGMENT
 
     axes: string, or a tuple of strings
         Choose the direction of the cuts (among 'x', 'y', or 'z')
@@ -328,8 +343,8 @@ def plot_segment(config, experiment_id, savefig=None, slices=None,
 
     """
     if animated and not raw:
-        msg = 'animated cannot be True with raw set to False. Switching raw'\
-                ' to True.'
+        msg = 'animated cannot be True with raw set to False. ' \
+              'Switching raw to True.'
         import logging as log
         log.warning(msg)
         raw = True
@@ -346,8 +361,8 @@ def plot_segment(config, experiment_id, savefig=None, slices=None,
     dest = tempfile.gettempdir()
     # Downloading resources
     try:
-        filepaths = download_resources(config, experiment_id, resource_name, dest,
-                                       raw=raw, cache=cache)
+        filepaths = download_resources(config, experiment_id, resource_name,
+                                       dest, raw=raw, cache=cache)
     except FileNotFoundError as exc:
         msg = '{0}. Retry with cache set to False.'.format(exc)
         raise FileNotFoundError(msg)
